@@ -6,9 +6,9 @@
 
 #include "texthandler.h"
 
-#include <connection.h>
-#include <quotient_common.h>
-#include <syncdata.h>
+#include <Quotient/quotient_common.h>
+#include <Quotient/syncdata.h>
+#include <qnamespace.h>
 
 using namespace Quotient;
 
@@ -49,7 +49,8 @@ private Q_SLOTS:
     void receiveStripReply();
     void receivePlainTextIn();
 
-    void recieveRichInPlainOut();
+    void receiveRichInPlainOut_data();
+    void receiveRichInPlainOut();
     void receivePlainStripHtml();
     void receivePlainStripMarkup();
     void receiveStripNewlines();
@@ -59,11 +60,17 @@ private Q_SLOTS:
     void receiveRichtextIn();
     void receiveRichMxcUrl();
     void receiveRichPlainUrl();
-
+    void receiveRichEmote();
+    void receiveRichEdited_data();
+    void receiveRichEdited();
     void receiveLineSeparator();
+
+    void linkPreviewsMatch_data();
+    void linkPreviewsMatch();
+    void linkPreviewsReject_data();
+    void linkPreviewsReject();
 };
 
-#ifdef QUOTIENT_07
 void TextHandlerTest::initTestCase()
 {
     connection = Connection::makeMockConnection(QStringLiteral("@bob:kde.org"));
@@ -148,7 +155,44 @@ void TextHandlerTest::initTestCase()
         "sender": "@example:example.org",
         "type": "m.room.message",
         "unsigned": {
-          "age": 1235
+          "age": 1232
+        }
+      },
+      {
+        "content": {
+          "body": "/me This is an emote.",
+          "format": "org.matrix.custom.html",
+          "formatted_body": "This is an emote.",
+          "msgtype": "m.emote"
+        },
+        "event_id": "$153273582443PhrSn:example.org",
+        "origin_server_ts": 1532735824654,
+        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
+        "sender": "@example:example.org",
+        "type": "m.room.message",
+        "unsigned": {
+          "age": 1231
+        }
+      },
+      {
+        "content": {
+            "body": "tested",
+            "msgtype": "m.text"
+        },
+        "event_id": "$zrCiBxBnqqTn0Z5FY78qSZAszno_w8nJJXzfBULG-3E",
+        "origin_server_ts": 1680948575928,
+        "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
+        "sender": "@example:example.org",
+        "type": "m.room.message",
+        "unsigned": {
+            "age": 1747776,
+            "m.relations": {
+                "m.replace": {
+                    "event_id": "$UX0PlpyI7vYO32iHMuuYEP7ECMh4sX3XLGiB2SwM4mQ",
+                    "origin_server_ts": 1680948580992,
+                    "sender": "@example:example.org"
+                }
+            }
         }
       }
     ],
@@ -159,7 +203,6 @@ void TextHandlerTest::initTestCase()
     SyncRoomData roomData(QStringLiteral("@bob:kde.org"), JoinState::Join, json.object());
     room->update(std::move(roomData));
 }
-#endif
 
 void TextHandlerTest::allowedAttributes()
 {
@@ -311,15 +354,24 @@ void TextHandlerTest::receiveStripReply()
     QCOMPARE(testTextHandler.handleRecievePlainText(), testOutputString);
 }
 
-void TextHandlerTest::recieveRichInPlainOut()
+void TextHandlerTest::receiveRichInPlainOut_data()
 {
-    const QString testInputString = QStringLiteral("a &amp; b");
-    const QString testOutputString = QStringLiteral("a & b");
+    QTest::addColumn<QString>("testInputString");
+    QTest::addColumn<QString>("testOutputString");
+
+    QTest::newRow("ampersand") << QStringLiteral("a &amp; b") << QStringLiteral("a & b");
+    QTest::newRow("quote") << QStringLiteral("&quot;a and b&quot;") << QStringLiteral("\"a and b\"");
+}
+
+void TextHandlerTest::receiveRichInPlainOut()
+{
+    QFETCH(QString, testInputString);
+    QFETCH(QString, testOutputString);
 
     TextHandler testTextHandler;
     testTextHandler.setData(testInputString);
 
-    QCOMPARE(testTextHandler.handleRecievePlainText(), testOutputString);
+    QCOMPARE(testTextHandler.handleRecievePlainText(Qt::RichText), testOutputString);
 }
 
 void TextHandlerTest::receivePlainTextIn()
@@ -425,7 +477,6 @@ void TextHandlerTest::receiveRichtextIn()
     QCOMPARE(testTextHandler.handleRecieveRichText(), testOutputString);
 }
 
-#ifdef QUOTIENT_07
 void TextHandlerTest::receiveRichMxcUrl()
 {
     const QString testInputString = QStringLiteral(
@@ -441,9 +492,8 @@ void TextHandlerTest::receiveRichMxcUrl()
     TextHandler testTextHandler;
     testTextHandler.setData(testInputString);
 
-    QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText, room, room->messageEvents().back().get()), testOutputString);
+    QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText, room, room->messageEvents().at(0).get()), testOutputString);
 }
-#endif
 
 /**
  * For when your rich input string has a plain text url left in.
@@ -500,6 +550,45 @@ void TextHandlerTest::receiveRichPlainUrl()
     QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText), testOutputStringMxId);
 }
 
+// Test that user pill is add to an emote message.
+// N.B. The second message in the test timeline is marked as an emote.
+void TextHandlerTest::receiveRichEmote()
+{
+    auto event = room->messageEvents().at(1).get();
+    auto author = static_cast<NeoChatUser *>(room->user(event->senderId()));
+    const QString testInputString = QStringLiteral("This is an emote.");
+    const QString testOutputString = QStringLiteral("* <a href=\"https://matrix.to/#/@example:example.org\" style=\"color:") + author->color().name()
+        + QStringLiteral("\">@example:example.org</a> This is an emote.");
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(testInputString);
+
+    QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText, room, event), testOutputString);
+}
+
+void TextHandlerTest::receiveRichEdited_data()
+{
+    QTest::addColumn<QString>("testInputString");
+    QTest::addColumn<QString>("testOutputString");
+
+    QTest::newRow("basic") << QStringLiteral("Edited") << QStringLiteral("Edited <span style=\"color:#000000\">(edited)</span>");
+    QTest::newRow("multiple paragraphs") << QStringLiteral("<p>Edited</p>\n<p>Edited</p>")
+                                         << QStringLiteral("<p>Edited</p>\n<p>Edited <span style=\"color:#000000\">(edited)</span></p>");
+    QTest::newRow("blockquote") << QStringLiteral("<blockquote>Edited</blockquote>")
+                                << QStringLiteral("<blockquote>Edited</blockquote><p> <span style=\"color:#000000\">(edited)</span></p>");
+}
+
+void TextHandlerTest::receiveRichEdited()
+{
+    QFETCH(QString, testInputString);
+    QFETCH(QString, testOutputString);
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(testInputString);
+
+    QCOMPARE(testTextHandler.handleRecieveRichText(Qt::RichText, room, room->messageEvents().at(2).get()), testOutputString);
+}
+
 void TextHandlerTest::receiveLineSeparator()
 {
     auto text = QStringLiteral("foo\u2028bar");
@@ -508,5 +597,52 @@ void TextHandlerTest::receiveLineSeparator()
     QCOMPARE(textHandler.handleRecievePlainText(Qt::PlainText, true), QStringLiteral("foo bar"));
 }
 
-QTEST_MAIN(TextHandlerTest)
+void TextHandlerTest::linkPreviewsMatch_data()
+{
+    QTest::addColumn<QString>("testInputString");
+    QTest::addColumn<QList<QUrl>>("testOutputLinks");
+
+    QTest::newRow("plainHttps") << QStringLiteral("https://kde.org") << QList<QUrl>({QUrl("https://kde.org")});
+    QTest::newRow("richHttps") << QStringLiteral("<a href=\"https://kde.org\">Rich Link</a>") << QList<QUrl>({QUrl("https://kde.org")});
+    QTest::newRow("plainWww") << QStringLiteral("www.example.org") << QList<QUrl>({QUrl("www.example.org")});
+    QTest::newRow("multipleHttps") << QStringLiteral("https://kde.org www.example.org")
+                                   << QList<QUrl>({
+                                          QUrl("https://kde.org"),
+                                          QUrl("www.example.org"),
+                                      });
+}
+
+void TextHandlerTest::linkPreviewsMatch()
+{
+    QFETCH(QString, testInputString);
+    QFETCH(QList<QUrl>, testOutputLinks);
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(testInputString);
+
+    QCOMPARE(testTextHandler.getLinkPreviews(), testOutputLinks);
+}
+
+void TextHandlerTest::linkPreviewsReject_data()
+{
+    QTest::addColumn<QString>("testInputString");
+    QTest::addColumn<QList<QUrl>>("testOutputLinks");
+
+    QTest::newRow("mxc") << QStringLiteral("mxc://example.org/SEsfnsuifSDFSSEF") << QList<QUrl>();
+    QTest::newRow("matrixTo") << QStringLiteral("https://matrix.to/#/@alice:example.org") << QList<QUrl>();
+    QTest::newRow("noSpace") << QStringLiteral("testhttps://kde.org") << QList<QUrl>();
+}
+
+void TextHandlerTest::linkPreviewsReject()
+{
+    QFETCH(QString, testInputString);
+    QFETCH(QList<QUrl>, testOutputLinks);
+
+    TextHandler testTextHandler;
+    testTextHandler.setData(testInputString);
+
+    QCOMPARE(testTextHandler.getLinkPreviews(), testOutputLinks);
+}
+
+QTEST_GUILESS_MAIN(TextHandlerTest)
 #include "texthandlertest.moc"
