@@ -3,23 +3,17 @@
 
 #include "actionshandler.h"
 
-#include "controller.h"
-
-#include <csapi/joining.h>
-#include <events/roommemberevent.h>
+#include <Quotient/csapi/joining.h>
+#include <Quotient/events/roommemberevent.h>
 
 #include <cmark.h>
 
 #include <KLocalizedString>
 #include <QStringBuilder>
 
-#include "controller.h"
 #include "models/actionsmodel.h"
 #include "models/customemojimodel.h"
 #include "neochatconfig.h"
-#include "neochatroom.h"
-#include "neochatuser.h"
-#include "roommanager.h"
 #include "texthandler.h"
 
 using namespace Quotient;
@@ -188,3 +182,5 @@ void ActionsHandler::checkEffects(const QString &text)
         Q_EMIT showEffect(*effect);
     }
 }
+
+#include "moc_actionshandler.cpp"
